@@ -24,7 +24,7 @@
 
 #include <dcopobject.h>
 #include <kontact/plugin.h>
-#include <tdepimmacros.h>
+#include <kdemacros.h>
 
 namespace Kontact
 {
